@@ -3,25 +3,11 @@ package Data::Frame::Rlike;
 use strict;
 use warnings;
 
-use Exporter 'import';
+use Data::Frame::Util qw(dataframe factor logical);
+
+use parent qw(Exporter::Tiny);
 our @EXPORT = qw(dataframe factor logical);
 
-use Data::Frame;
-use PDL::Factor ();
-use PDL::Logical ();
-
-sub dataframe {
-	Data::Frame->new( columns => \@_ );
-}
-
-sub factor {
-	PDL::Factor->new(@_);
-}
-
-sub logical {
-	PDL::Logical->new(@_);
-}
-
 1;
 
 __END__
@@ -36,7 +22,7 @@ Data::Frame::Rlike
 
 =head1 VERSION
 
-version 0.0041
+version 0.0043
 
 =head1 DESCRIPTION
 
